/*
    TRAMPALIEN: A silly little trampoline gunman game 
	by Troy Davis (GPF)
	Design and concept by John W. Szczepaniak
	
	Code original based on Aliens
    Copyright (C) 1998  Sam Lantinga

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#include <stdlib.h>
#include <stdio.h>
#include <time.h>

#include "SDL.h"
#include "SDL_mixer.h"
#include "SDL_image.h"

#ifdef macintosh
#define DIR_SEP	":"
#define DIR_CUR ":"
#endif
#ifdef _arch_dreamcast
#include "kos.h"
#define DIR_SEP	"/"
#define DIR_CUR "/rd/"
#else
#define DIR_SEP	"/"
#define DIR_CUR	"romdisk/"
#endif
#define DATAFILE(X)	DIR_CUR "data" DIR_SEP X

#define	FRAMES_PER_SEC	50

int speed;
int player2speed;
Uint8 *keys;
int exitgame;
int menu;
#define MAX_SHOTS			2
#define MENU				1
#define SHOT_SPEED			4
#define PLAYER_SLOW_SPEED	1
#define PLAYER_MED_SPEED	2
#define PLAYER_FAST_SPEED	3
#define PLAYER2_SLOW_SPEED	1
#define PLAYER2_MED_SPEED	2
#define PLAYER2_FAST_SPEED	3
#define EXPLODE_TIME		4
#define BLAST_TIME			10
#define ACCEL_TIME			20

#define NUMLIFES			2 //It will use NUMLIFES + 1

#define DEADTIME			100
#define SCREENWIDTH 640
#define SCREENHEIGHT 480

#ifdef _arch_dreamcast
	int joyval=12;
#else
	int joyval=3200;
#endif
static int num_joys=0;
static SDL_Joystick *joys[4];
#define JOY_UP(num) (num_joys>num && SDL_JoystickGetAxis(joys[num], 1)<-joyval)
#define JOY_DOWN(num) (num_joys>num && SDL_JoystickGetAxis(joys[num], 1)>joyval)
#define JOY_RIGHT(num) (num_joys>num && SDL_JoystickGetAxis(joys[num], 0)>joyval)
#define JOY_LEFT(num) (num_joys>num && SDL_JoystickGetAxis(joys[num], 0)<-joyval)
#define JOY_FIRE(num) (num_joys>num && SDL_JoystickGetButton(joys[num], 0))
#define JOY_START(num) (num_joys>num && SDL_JoystickGetButton(joys[num], 4))
#define JOY_HATUP(num) (num_joys>num && (SDL_JoystickGetHat(joys[num], 0) & SDL_HAT_UP))
#define JOY_HATDOWN(num) (num_joys>num && (SDL_JoystickGetHat(joys[num], 0) & SDL_HAT_DOWN))
#define JOY_HATRIGHT(num) (num_joys>num && (SDL_JoystickGetHat(joys[num], 0) & SDL_HAT_RIGHT))
#define JOY_HATLEFT(num) (num_joys>num && (SDL_JoystickGetHat(joys[num], 0) & SDL_HAT_LEFT))

#define KEY_START SDLK_SPACE
#define KEY_START2 SDLK_p

#define KEY_PL1_UP SDLK_w
#define KEY_PL1_DOWN SDLK_s
#define KEY_PL1_LEFT SDLK_q
#define KEY_PL1_RIGHT SDLK_e
#define KEY_PL1_FIRE SDLK_d

#define KEY_PL2_UP SDLK_UP
#define KEY_PL2_DOWN SDLK_DOWN
#define KEY_PL2_LEFT SDLK_LEFT
#define KEY_PL2_RIGHT SDLK_RIGHT
#define KEY_PL2_FIRE SDLK_RCTRL

typedef struct {
	int action_up,action_down,action_fire,action_left,action_right,action_start;
	int alive;
	int facing;
	int x, y;
	SDL_Surface *image;
} object;

#ifdef _arch_dreamcast
extern uint8 romdisk[]; 
KOS_INIT_ROMDISK(romdisk);
#endif
/**/
SDL_Surface *screen;
SDL_Surface *background;
SDL_Surface *title;

/**/
object player;
object playerdown;
object playerup;
object playerdead;
int reloading;
int reloading2;

int accel;
int accel2;
int dccel;
int dccel2;
int raccel;
int raccel2;
int laccel;
int laccel2;
int startbutton;

int score=0;
int score2=0;
int lifes;
int lifes2;
int player2maxshot;
int playermaxshot;

SDL_Event event;

object shots[MAX_SHOTS];
object shots2[MAX_SHOTS];
object reload;
object reload2;
object tramp;
object tramp2;
object life[NUMLIFES];
object life2[NUMLIFES];
object vsbattle;
object iconptr;
int roundcount;
object scorenum;
object scorenum2;

object blastright;
object blastleft;
object blastdown;
object blastup;
object blast2down;
object blast2up;

object ammotot[MAX_SHOTS];
object ammotot2[MAX_SHOTS];
/**/
object player2;
object player2down;
object player2up;
object player2dead;
/**/
object explosions;
object explosions2;
object round;
object round2;
object playerwins;
object player2wins;
/**/
#define MAX_UPDATES	6*(4+MAX_SHOTS)
int numupdates;
object numbers[10];
SDL_Rect srcupdate[MAX_UPDATES];
SDL_Rect dstupdate[MAX_UPDATES];
struct blit {
	SDL_Surface *src;
	SDL_Rect *srcrect;
	SDL_Rect *dstrect;
} blits[MAX_UPDATES];
/**/

#if defined(PLAY_MOD) || defined(PLAY_MID)
Mix_Music *music;
#endif
enum {
	MUSIC_WAV,
	SHOT_WAV,
	EXPLODE_WAV,
	EXPLODE2_WAV,
	TITLE_WAV,
	PWIN_WAV,
	P2WIN_WAV,
	ROUND_WAV,
	ONE_WAV,
	TWO_WAV,
	THREE_WAV,
	FOUR_WAV,
	FIVE_WAV,
	SIX_WAV,
	SEVEN_WAV,
	EIGHT_WAV,
	NINE_WAV,
	NUM_WAVES
};
Mix_Chunk *sounds[NUM_WAVES];

SDL_Surface *LoadImage(char *datafile, int transparent)
{
	SDL_Surface *image, *surface;

	image = IMG_Load(datafile);
	if ( image == NULL ) {
		fprintf(stderr, "Couldn't load image %s: %s\n",
					datafile, IMG_GetError());
		return(NULL);
	}
	if ( transparent ) {
		/* Assuming 8-bit BMP image */
		SDL_SetColorKey(image, (SDL_SRCCOLORKEY|SDL_RLEACCEL),
						*(Uint8 *)image->pixels);
	}
	surface = SDL_DisplayFormat(image);
	SDL_FreeSurface(image);
	return(surface);
}

void update_player_actions(void)
{
	int tmp;

	tmp = (keys[KEY_START] == SDL_PRESSED) || JOY_START(0);
	player.action_start=tmp;

	tmp = (keys[KEY_START2] == SDL_PRESSED) || JOY_START(1);
	player2.action_start=tmp;
 	
	tmp = (keys[KEY_PL1_UP] == SDL_PRESSED) || JOY_UP(0) || JOY_HATUP(0);
	player.action_up=tmp;

	tmp = (keys[KEY_PL1_DOWN] == SDL_PRESSED) || JOY_DOWN(0)|| JOY_HATDOWN(0);
	player.action_down=tmp;

	tmp = (keys[KEY_PL1_RIGHT] == SDL_PRESSED) || JOY_RIGHT(0) || JOY_HATRIGHT(0);
	player.action_right=tmp;

	tmp = (keys[KEY_PL1_LEFT] == SDL_PRESSED) || JOY_LEFT(0)|| JOY_HATLEFT(0);
	player.action_left=tmp;
	
	tmp = (keys[KEY_PL1_FIRE] == SDL_PRESSED) || JOY_FIRE(0);
	player.action_fire=tmp;

	tmp = (keys[KEY_PL2_UP] == SDL_PRESSED) || JOY_UP(1)|| JOY_HATUP(1);
	player2.action_up=tmp;

	tmp = (keys[KEY_PL2_DOWN] == SDL_PRESSED) || JOY_DOWN(1) ||JOY_HATDOWN(1);
	player2.action_down=tmp;
	
	tmp = (keys[KEY_PL2_RIGHT] == SDL_PRESSED) || JOY_RIGHT(1) || JOY_HATRIGHT(1);
	player2.action_right=tmp;

	tmp = (keys[KEY_PL2_LEFT] == SDL_PRESSED) || JOY_LEFT(1)|| JOY_HATLEFT(1);
	player2.action_left=tmp;
	
	tmp = (keys[KEY_PL2_FIRE] == SDL_PRESSED) || JOY_FIRE(1);
	player2.action_fire=tmp;

}

int LoadData(void)
{
	int i;

	/* Load sounds */
#if defined(PLAY_MOD) || defined(PLAY_MID)
#if defined(PLAY_MOD)
	music = Mix_LoadMUS(DATAFILE("music.it"));
		//fprintf(stderr, "Playing Mod\n");
#elif defined(PLAY_MID)
	music = Mix_LoadMUS(DATAFILE("music.mid"));
	//fprintf(stderr, "Playing Midi\n");
#endif
	if ( music == NULL ) {
		fprintf(stderr, "Warning: Couldn't load music: %s\n",
							Mix_GetError());
	}
#else
	sounds[MUSIC_WAV] = Mix_LoadWAV(DATAFILE("music.wav"));
#endif
	sounds[SHOT_WAV] = Mix_LoadWAV(DATAFILE("shot.wav"));
	sounds[EXPLODE_WAV] = Mix_LoadWAV(DATAFILE("explode.wav"));
	sounds[EXPLODE2_WAV] = Mix_LoadWAV(DATAFILE("explode.wav"));
	sounds[TITLE_WAV] = Mix_LoadWAV(DATAFILE("title.wav"));
	sounds[PWIN_WAV] = Mix_LoadWAV(DATAFILE("T1W.wav"));
	sounds[P2WIN_WAV] = Mix_LoadWAV(DATAFILE("T2W.wav"));
	
	sounds[ROUND_WAV] = Mix_LoadWAV(DATAFILE("round.wav"));
	sounds[ONE_WAV] = Mix_LoadWAV(DATAFILE("1.wav"));
	sounds[TWO_WAV] = Mix_LoadWAV(DATAFILE("2.wav"));
	sounds[THREE_WAV] = Mix_LoadWAV(DATAFILE("3.wav"));
	sounds[FOUR_WAV] = Mix_LoadWAV(DATAFILE("4.wav"));
	sounds[FIVE_WAV] = Mix_LoadWAV(DATAFILE("5.wav"));
	sounds[SIX_WAV] = Mix_LoadWAV(DATAFILE("6.wav"));
	sounds[SEVEN_WAV] = Mix_LoadWAV(DATAFILE("7.wav"));
	sounds[EIGHT_WAV] = Mix_LoadWAV(DATAFILE("8.wav"));
	sounds[NINE_WAV] = Mix_LoadWAV(DATAFILE("9.wav"));	

	/* Load graphics */
	player.image = LoadImage(DATAFILE("char.gif"), 1);
	if ( player.image == NULL ) {
		return(0);
	}
	playerdown.image = LoadImage(DATAFILE("charDwn.gif"), 1);
	if ( playerdown.image == NULL ) {
		return(0);
	}
	playerup.image = LoadImage(DATAFILE("charUp.gif"), 1);
	if ( playerup.image == NULL ) {
		return(0);
	}
	playerdead.image = LoadImage(DATAFILE("charded.gif"), 1);
	if ( playerdead.image == NULL ) {
		return(0);
	}
	shots[0].image = LoadImage(DATAFILE("bullet.gif"), 0);
	if ( shots[0].image == NULL ) {
		return(0);
	}
	else 
	{
 		shots2[0].image = shots[0].image;
		for ( i=1; i<MAX_SHOTS; ++i ) {
			shots[i].image = shots[0].image;
			shots2[i].image = shots2[0].image;
		}
	}
	shots2[0].image = LoadImage(DATAFILE("bullet2.gif"), 0);
	if ( shots2[0].image == NULL ) {
		return(0);
	}
	else 
	{
		for ( i=1; i<MAX_SHOTS; ++i ) {
			shots2[i].image = shots2[0].image;
		}
	}	
	blastright.image = LoadImage(DATAFILE("blstRght.gif"), 0);
	if ( blastright.image == NULL ) {
		return(0);
	}
	blastleft.image = LoadImage(DATAFILE("blstLft.gif"), 0);
	if ( blastleft.image == NULL ) {
		return(0);
	}
	blastdown.image = LoadImage(DATAFILE("blstDwn.gif"), 0);
	if ( blastdown.image == NULL ) {
		return(0);
	}
	blastup.image = LoadImage(DATAFILE("blstUp.gif"), 0);
	if ( blastup.image == NULL ) {
		return(0);
	}
	blast2down.image = LoadImage(DATAFILE("blst2Dwn.gif"), 0);
	if ( blast2down.image == NULL ) {
		return(0);
	}
	blast2up.image = LoadImage(DATAFILE("blst2Up.gif"), 0);
	if ( blast2up.image == NULL ) {
		return(0);
	}
	reload.image = LoadImage(DATAFILE("reload.gif"), 0);
	if ( reload.image == NULL ) {
		return(0);
	}
	reload2.image = LoadImage(DATAFILE("reload2.gif"), 0);
	if ( reload2.image == NULL ) {
		return(0);
	}
	tramp.image = LoadImage(DATAFILE("tramp.gif"), 0);
	if ( tramp.image == NULL ) {
		return(0);
	}
	else
 		tramp2.image = tramp.image;


	ammotot[0].image = LoadImage(DATAFILE("ammotot.gif"), 0);
	if ( ammotot[0].image == NULL ) {
		return(0);
	}
	else 
	{
		ammotot2[0].image = ammotot[0].image;
		for ( i=1; i<MAX_SHOTS; ++i ) 
		{
			ammotot[i].image = ammotot[0].image;
			ammotot2[i].image = ammotot[0].image;
		}
	}

	player2.image = LoadImage(DATAFILE("char2.gif"), 1);
	if ( player2.image == NULL ) {
		return(0);
	}
	player2down.image = LoadImage(DATAFILE("char2Dwn.gif"), 1);
	if ( player2down.image == NULL ) {
		return(0);
	}
	player2up.image = LoadImage(DATAFILE("char2Up.gif"), 1);
	if ( player2up.image == NULL ) {
		return(0);
	}
	player2dead.image = LoadImage(DATAFILE("charded2.gif"), 1);
	if ( player2dead.image == NULL ) {
		return(0);
	}
	explosions.image = LoadImage(DATAFILE("explsion.gif"), 1);
	if ( explosions.image == NULL ) {
		return(0);
	}
	else
		explosions2.image = explosions.image;

	background = LoadImage(DATAFILE("back.gif"), 0);
	if ( background == NULL ) {
		return(0);
	}
	title = LoadImage(DATAFILE("title.gif"), 0);
	if ( title == NULL ) {
		return(0);
	}
	vsbattle.image = LoadImage(DATAFILE("vsbattle.gif"), 0);
	if ( vsbattle.image == NULL ) {
		return(0);
	}

	iconptr.image = LoadImage(DATAFILE("icon.gif"), 0);
	if ( iconptr.image == NULL ) {
		return(0);
	}
 	
	round.image = LoadImage(DATAFILE("round.gif"), 0);
	if ( round.image == NULL ) {
		return(0);
	}
	playerwins.image = LoadImage(DATAFILE("pwins.gif"), 0);
	if ( playerwins.image == NULL ) {
		return(0);
	}
	player2wins.image = LoadImage(DATAFILE("p2wins.gif"), 0);
	if ( player2wins.image == NULL ) {
		return(0);
	}
	
	life[0].image = LoadImage(DATAFILE("life.gif"), 0);
	if ( life[0].image == NULL ) {
		return(0);
	}
	else 
	{
		life2[0].image = life[0].image;
		for ( i=1; i<NUMLIFES; ++i ) 
		{
			life[i].image = life[0].image;
			life2[i].image = life2[0].image;
		}
	}

//	for ( i=0; i<3; ++i ) 
//	{
//		char tmp[10];
//		sprintf(tmp,"%s%d.gif",DATAFILE(""),i);
//		printf("name = %s\n",tmp);
//		numbers[i].image = LoadImage(tmp, 0);
//		if ( numbers[i].image == NULL ) {
//			return(0);
//		}		
//	}
	numbers[0].image = LoadImage(DATAFILE("0.gif"), 0);
	numbers[1].image = LoadImage(DATAFILE("1.gif"), 0);
	numbers[2].image = LoadImage(DATAFILE("2.gif"), 0);
	numbers[3].image = LoadImage(DATAFILE("3.gif"), 0);
	numbers[4].image = LoadImage(DATAFILE("4.gif"), 0);
	numbers[5].image = LoadImage(DATAFILE("5.gif"), 0);
	numbers[6].image = LoadImage(DATAFILE("6.gif"), 0);
	numbers[7].image = LoadImage(DATAFILE("7.gif"), 0);
	numbers[8].image = LoadImage(DATAFILE("8.gif"), 0);
	numbers[9].image = LoadImage(DATAFILE("9.gif"), 0);  	
	
	/* Set up the update rectangle pointers */
	for ( i=0; i<MAX_UPDATES; ++i ) {
		blits[i].srcrect = &srcupdate[i];
		blits[i].dstrect = &dstupdate[i];
	}
	return(1);
}

void FreeData(void)
{
	int i;

	/* Free sounds */
#if defined(PLAY_MOD) || defined(PLAY_MID)
	Mix_FreeMusic(music);
#endif
	for ( i=0; i<NUM_WAVES; ++i ) {
		Mix_FreeChunk(sounds[i]);
	}

	/* Free graphics */
	SDL_FreeSurface(player.image);
	SDL_FreeSurface(playerdown.image);
	SDL_FreeSurface(playerup.image);
	SDL_FreeSurface(shots[0].image);
	SDL_FreeSurface(player2.image);
	SDL_FreeSurface(explosions.image);
	SDL_FreeSurface(background);
	SDL_FreeSurface(reload.image);
	SDL_FreeSurface(blastright.image);
	SDL_FreeSurface(blastleft.image);
	SDL_FreeSurface(blastdown.image);
	SDL_FreeSurface(blastup.image);
	SDL_FreeSurface(blast2down.image);
	SDL_FreeSurface(blast2up.image);
	SDL_FreeSurface(tramp.image);
	SDL_FreeSurface(ammotot[0].image);
//	SDL_FreeSurface(scorenum[0].image);
	SDL_FreeSurface(life[0].image);
	SDL_FreeSurface(round.image);
	SDL_FreeSurface(playerwins.image);
	SDL_FreeSurface(player2wins.image);
	SDL_FreeSurface(playerdead.image);
	SDL_FreeSurface(player2dead.image);
	SDL_FreeSurface(title);
}

void DrawObject(object *sprite)
{
	struct blit *update;

	update = &blits[numupdates++];
	update->src = sprite->image;
	update->srcrect->x = 0;
	update->srcrect->y = 0;
	update->srcrect->w = sprite->image->w;
	update->srcrect->h = sprite->image->h;
	update->dstrect->x = sprite->x;
	update->dstrect->y = sprite->y;
	update->dstrect->w = sprite->image->w;
	update->dstrect->h = sprite->image->h;
}
void EraseObject(object *sprite)
{
	struct blit *update;
	int wrap;

	/* The background wraps horizontally across the screen */
	update = &blits[numupdates++];
	update->src = background;
	update->srcrect->x = sprite->x%background->w;
	update->srcrect->y = sprite->y;
	update->srcrect->w = sprite->image->w;
	update->srcrect->h = sprite->image->h;
	wrap = (update->srcrect->x+update->srcrect->w)-(background->w);
	if ( wrap > 0 ) {
		update->srcrect->w -= wrap;
	}
	update->dstrect->x = sprite->x;
	update->dstrect->y = sprite->y;
	update->dstrect->w = update->srcrect->w;
	update->dstrect->h = update->srcrect->h;

	/* Assuming sprites can only wrap across one background tile */
	if ( wrap > 0 ) {
		update = &blits[numupdates++];
		update->src = background;
		update->srcrect->x = 0;
		update->srcrect->y = sprite->y;
		update->srcrect->w = wrap;
		update->srcrect->h = sprite->image->h;
		update->dstrect->x =((sprite->x/background->w)+1)*background->w;
		update->dstrect->y = sprite->y;
		update->dstrect->w = update->srcrect->w;
		update->dstrect->h = update->srcrect->h;
	}
}
void UpdateScreen(void)
{
	int i;

	for ( i=0; i<numupdates; ++i ) {
		SDL_LowerBlit(blits[i].src, blits[i].srcrect,
						screen, blits[i].dstrect);
	}
	SDL_UpdateRects(screen, numupdates, dstupdate);
	numupdates = 0;
}

int Collide(object *sprite1, object *sprite2)
{
	if ( (sprite1->y >= (sprite2->y+sprite2->image->h)) ||
	     (sprite1->x >= (sprite2->x+sprite2->image->w)) ||
	     (sprite2->y >= (sprite1->y+sprite1->image->h)) ||
	     (sprite2->x >= (sprite1->x+sprite1->image->w)) ) {
		return(0);
	}
	return(1);
	     
}

void WaitFrame(void)
{
	static Uint32 next_tick = 0;
	Uint32 this_tick;

	/* Wait for the next frame */
	this_tick = SDL_GetTicks(); 
	if ( this_tick < next_tick ) {
		SDL_Delay(next_tick-this_tick);
	}
	next_tick = this_tick + (1000/FRAMES_PER_SEC);

}

void Paintbackground(SDL_Surface *background)
{
	
	/* Paint the background */
	numupdates = 0;
	for (int i=0; i<screen->w; i += background->w ) {
		SDL_Rect dst;

		dst.x = i;
		dst.y = 0;
		dst.w = background->w;
		dst.h = background->h;
		SDL_BlitSurface(background, NULL, screen, &dst);
	}
	SDL_UpdateRect(screen, 0, 0, 0, 0);
}
/* This of course can be optimized :-) */
void RunGame(int numberofrounds, int numberofplayers)
{

	int i, j,k;
	int newround =1;
	int roundcount = 1;
	int notdead =1;
	int paused=0;
	int paused2=0;
	int start=0;
	int start2=0;
	while ( (score != numberofrounds) || (score2 != numberofrounds) )
	{

		Paintbackground(background);
	

		if ( newround )
		{
			newround=0;

			player2maxshot =MAX_SHOTS;
			playermaxshot=MAX_SHOTS;
			//Round 1 starting
			for ( i=0; i<NUMLIFES; ++i ) {
				life[i].alive = 1;
				life2[i].alive = 1;
			}
			player.alive=1;
			player2.alive=1;
			speed=PLAYER_MED_SPEED;
			player2speed=PLAYER2_MED_SPEED;
			lifes =0;
			lifes2=0;
	
			round.x=SCREENWIDTH/2-80;
			round.y=SCREENHEIGHT/2;
			DrawObject(&round);
			UpdateScreen();

			numbers[roundcount].x=round.x+95;
			numbers[roundcount].y=round.y;
			DrawObject(&numbers[roundcount]);
			
			Mix_PlayChannel(ROUND_WAV, sounds[ROUND_WAV], 0);
			while ( Mix_Playing(ROUND_WAV) ) {WaitFrame();}			
			Mix_PlayChannel(ROUND_WAV, sounds[ROUND_WAV+roundcount], 0);

			UpdateScreen();
			SDL_Delay(2000); 
			EraseObject(&round);
			EraseObject(&numbers[roundcount]);
			UpdateScreen();

			player.x = 38;
			player.y = (rand()%400)+45;
			player.facing = 1;
			player.action_up = 0;
	 		player.action_down=0;
	  		player.action_fire=0;
			DrawObject(&player);
	
	        player2.facing= 1;
			player2.x = SCREENWIDTH-85;
			player2.y = (rand()%400)+45;
			player2.action_up  =0;
	 		player2.action_down=0;
	  		player2.action_fire=0;
			DrawObject(&player2);			
		
			/* Initialize the objects */
			reload.alive=1;
			reload.x = 30;
			reload.y = 15;
			reload.facing=1;
			reload2.alive=1;
			reload2.x = SCREENWIDTH-85;
			reload2.y = 15;
			reload2.facing=1;
			DrawObject(&reload);
			DrawObject(&reload2);


			tramp.alive=1;
			tramp.x = 12;
			tramp.y = 400;
			tramp.facing=1;
			tramp2.alive=1;
			tramp2.x = SCREENWIDTH-99;
			tramp2.y = 400;
			tramp2.facing=1;
			DrawObject(&tramp);
			DrawObject(&tramp2);

			for ( i=0; i<MAX_SHOTS; ++i ) 
			{
				ammotot[i].alive=1;
				ammotot[i].x = 25+(i*20);
				ammotot[i].y = 445;
				ammotot[i].facing=1;
				DrawObject(&ammotot[i]);

				ammotot2[i].alive=1;
				ammotot2[i].x = (SCREENWIDTH-40)-(i*20);
				ammotot2[i].y = 445;
				ammotot2[i].facing=1;
				DrawObject(&ammotot2[i]);
			}
			
			for ( i=0; i<MAX_SHOTS; ++i ) {
				shots[i].alive = 0;
				shots2[i].alive = 0;
			}

			for ( i=0; i<NUMLIFES; ++i ) 
			{
				life[i].x = 22+(i*25);
				life[i].y = 420;
				DrawObject(&life[i]);

				life2[i].x = (SCREENWIDTH-55)-(i*25);
				life2[i].y = 420;
				DrawObject(&life2[i]);
			}

			SDL_UpdateRect(screen, 0, 0, 0, 0);

			UpdateScreen();
		
		}

		while ( notdead) //(player.alive && player2.alive) || playerdead.alive || player2dead.alive)
		{
		
			/* Wait for the next frame */
			WaitFrame();
			
			keys = SDL_GetKeyState(NULL);
			/* Poll input queue, run keyboard loop */
			while ( SDL_PollEvent(&event) ) {
				if ( event.type == SDL_QUIT )
					return;
			}
			keys = SDL_GetKeyState(NULL);
				/* Check for keyboard abort */
			if ( keys[SDLK_ESCAPE] == SDL_PRESSED  ) {
				menu =1;
				return;
			}

			
			
			update_player_actions();
			
			if (player.action_start && !start)
			{ 
				if (!paused2)
					paused=!paused;
			}
			if (player2.action_start && !start2)
			{ 
				if (!paused)
					paused2=!paused2;
			}
			start=player.action_start;
			start2=player2.action_start;

			if (!paused && !paused2)
			{
			/* Erase everything from the screen */
			for ( i=0; i<MAX_SHOTS; ++i ) {
				if ( shots[i].alive ) {
					EraseObject(&shots[i]);
				}
				if ( shots2[i].alive ) {
					EraseObject(&shots2[i]);
				}
			}
			if ( player2down.alive)
			{
				EraseObject(&player2down);
			}
			else if ( player2up.alive)
			{
				EraseObject(&player2up);
			}
			else if (player2dead.alive >0)
			{
				EraseObject(&player2dead);
			}
			else if ( player2.alive)
			{
				EraseObject(&player2);
			}
			
			if ( player2down.alive ) {
				--player2down.alive;
			}

			if ( player2up.alive ) {
				--player2up.alive;
			}
			
			if ( playerdown.alive)
			{
				EraseObject(&playerdown);
			}
			else if ( playerup.alive)
			{
				EraseObject(&playerup);
			}
			else if (playerdead.alive >0)
			{
				EraseObject(&playerdead);
			}
			else if ( player.alive)
			{
				EraseObject(&player);
			}
			
			if ( playerdown.alive ) {
				--playerdown.alive;
			}

			if ( playerup.alive ) {
				--playerup.alive;
			}
			
			if ( explosions.alive ) {
				EraseObject(&explosions);
			}
			if ( explosions2.alive ) {
				EraseObject(&explosions2);
			}
			if ( blastright.alive) {
				EraseObject(&blastright);
			}

			if ( blastright.alive ) {
				--blastright.alive;
			}

			if ( blastleft.alive) {
				EraseObject(&blastleft);
			}

			if ( blastleft.alive ) {
				--blastleft.alive;
			}
			if ( blastdown.alive) {
				EraseObject(&blastdown);
			}

			if ( blastdown.alive ) {
				--blastdown.alive;
			}

			if ( blastup.alive) {
				EraseObject(&blastup);
			}

			if ( blastup.alive ) {
				--blastup.alive;
			}

			if ( blast2down.alive) {
				EraseObject(&blast2down);
			}

			if ( blast2down.alive ) {
				--blast2down.alive;
			}

			if ( blast2up.alive) {
				EraseObject(&blast2up);
			}

			if ( blast2up.alive ) {
				--blast2up.alive;
			}
			if ( playerdead.alive >0 ) {
				--playerdead.alive;
			}
   			if ( !playerdead.alive == 0) {
				player.alive =1;
				//player2.alive =1;
			}			
			if ( player2dead.alive >0 ) {
				--player2dead.alive;
			}	
   			if ( !player2dead.alive == 0) {
	   			//player.alive =1;
				player2.alive =1;
			}
			/* Decrement the lifetime of the explosions */
				if ( explosions.alive ) {
					--explosions.alive;
				}
				if ( explosions2.alive ) {
					--explosions2.alive;
				}			
			for ( i=0; i<MAX_SHOTS; ++i ) {
				if ( ammotot[i].alive ) {
					EraseObject(&ammotot[i]);
				}
				if ( ammotot2[i].alive ) {
					EraseObject(&ammotot2[i]);
				}
			}

			for ( i=0; i<NUMLIFES; ++i ) {
				if ( !life[i].alive ) {
					EraseObject(&life[i]);
				}
				if ( !life2[i].alive ) {
					EraseObject(&life2[i]);
				}
			}
//			for ( i=0; i<numberofrounds; ++i ) {
				if ( scorenum.alive ) {
					EraseObject(&scorenum);
				}
				if ( scorenum2.alive ) {
					EraseObject(&scorenum2);
				}
//			}

			//if(player.alive || player2.alive)
			//{
			/* Create new shots */
			if (player.action_fire && !reloading)
  			{
					for ( i=0; i<MAX_SHOTS; ++i ) {
						if ( ! shots[i].alive ) {
							break;
						}
					}
					if ( i != MAX_SHOTS && playermaxshot >=1) {
						shots[i].x = player.x+(player.image->w);
						shots[i].y = player.y+(player.image->h/2);
						shots[i].alive = 1;
						blastright.alive=BLAST_TIME;
						for ( j=0; j<MAX_SHOTS; ++j ) 
						{
							if ( ammotot[j].alive)
							{
								ammotot[j].alive=0;
								--playermaxshot;
								break;
							}
						}
						Mix_PlayChannel(SHOT_WAV,
								sounds[SHOT_WAV], 0);
					}
			}
			reloading = player.action_fire;
			
			/* Create new shots */
			if (numberofplayers == 2)
			{
				if (player2.action_fire && !reloading2)
   				{
						for ( i=0; i<MAX_SHOTS; ++i ) {
							if ( ! shots2[i].alive ) {
								break;
							}
						}
						if ( i != MAX_SHOTS && player2maxshot >=1) {
							shots2[i].x = player2.x;
							shots2[i].y = player2.y+(player2.image->h/2);
							shots2[i].alive = 1;
							blastleft.alive=BLAST_TIME;
							for ( j=0; j<MAX_SHOTS; ++j ) 
							{
								if ( ammotot2[j].alive)
								{
									ammotot2[j].alive=0;
									--player2maxshot;
									break;
								}
							}
							Mix_PlayChannel(SHOT_WAV,
									sounds[SHOT_WAV], 0);
						}
				}
				reloading2 = player2.action_fire;
			}
			else
			{
				k=rand()%5;
				if (k==1)
				{
					for ( i=0; i<MAX_SHOTS; ++i )
					{
						if ( ! shots2[i].alive ) 
						{
							break;
						}
					}
					if ( i != MAX_SHOTS && player2maxshot >=1 )
					{
						shots2[i].x = player2.x;
						shots2[i].y = player2.y+(player2.image->h/2);
						shots2[i].alive = 1;
						blastleft.alive=BLAST_TIME;
						for ( j=0; j<MAX_SHOTS; ++j ) 
						{
							if ( ammotot2[j].alive)
							{
								ammotot2[j].alive=0;
								--player2maxshot;
								break;
							}
						}
						Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
					}
				}
			}
			

			/* Move the player */
			if (player.action_up && !accel)
   			{
   				if ( playermaxshot >=1)
      			{
					
      				for ( j=0; j<MAX_SHOTS; ++j )
      				{
      					if ( ammotot[j].alive)
      					{
      						ammotot[j].alive=0;
   							--playermaxshot;

							if (player.facing==1)
							{
								//printf("facing\n");
								if (speed == PLAYER_SLOW_SPEED)
								{
   									speed = PLAYER_MED_SPEED;
								}
								else if (speed == PLAYER_MED_SPEED)
								{
									speed = PLAYER_FAST_SPEED;
								}
								playerup.alive=ACCEL_TIME;
								EraseObject(&player);
								blastup.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
							else
							{
								//printf("not facing\n");
								if (speed == PLAYER_FAST_SPEED)
								{
   									speed = PLAYER_MED_SPEED;
								}
								else if (speed == PLAYER_MED_SPEED)
								{
									speed = PLAYER_SLOW_SPEED;
								}
								playerup.alive=ACCEL_TIME;
								EraseObject(&player);
								blastup.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
   							break;
						}
					}
				 }

			}
			accel = player.action_up;
			
			if (player.action_down && !dccel)
			{	
   				if ( playermaxshot >=1)
      			{
      				for ( j=0; j<MAX_SHOTS; ++j ) 
      				{
      					if ( ammotot[j].alive)
      					{
      						ammotot[j].alive=0;
   							--playermaxshot;
							if (player.facing==1)
							{
								//printf("facing\n");
								if (speed == PLAYER_FAST_SPEED)
								{
   									speed = PLAYER_MED_SPEED;
								}
								else if (speed == PLAYER_MED_SPEED)
								{
									speed = PLAYER_SLOW_SPEED;
								}
								playerdown.alive=ACCEL_TIME;
								EraseObject(&player);
								blastdown.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
							else
							{
								//printf("not facing\n");
								if (speed == PLAYER_SLOW_SPEED)
								{
   									speed = PLAYER_MED_SPEED;
								}
								else if (speed == PLAYER_MED_SPEED)
								{
									speed = PLAYER_FAST_SPEED;
								}
								playerdown.alive=ACCEL_TIME;
								EraseObject(&player);
								blastdown.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
   							break;
						}
					}
				 }
				 
			}
			dccel = player.action_down;

//right
			if (player.action_right )//&& !raccel)
			{	
   				player.x=player.x+1;
 			}
			raccel = player.action_right;
 //end right  		
 //left
 			if (player.action_left )//&& !laccel)
			{	
   				player.x=player.x-1;
	 
			}
			laccel = player.action_left;
//end left	
//right
			if (player2.action_right )//&& !raccel2)
			{	
   				player2.x=player2.x+1;
			}
			raccel2 = player2.action_right;
 //end right  		
 //left
 			if (player2.action_left )//&& !laccel2)
			{	
   				player2.x=player2.x-1;
			}
			laccel2 = player2.action_left;
//end left	
			/* Move the player 2*/
			if (numberofplayers == 2)
			{
				if (player2.action_up && !accel2)
   				{
   					if ( player2maxshot >=1)
      				{
						
      					for ( j=0; j<MAX_SHOTS; ++j )
      					{
      						if ( ammotot2[j].alive)
      						{
      							ammotot2[j].alive=0;
   								--player2maxshot;

								if (player2.facing==1)
								{
									//printf("facing\n");
									if (player2speed == PLAYER2_SLOW_SPEED)
									{
   										player2speed = PLAYER2_MED_SPEED;
									}
									else if (player2speed == PLAYER2_MED_SPEED)
									{
										player2speed = PLAYER2_FAST_SPEED;
									}
									player2up.alive=ACCEL_TIME;
									EraseObject(&player2);
									blast2up.alive=BLAST_TIME;
									Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
								}
								else
								{
									//printf("not facing\n");
									if (player2speed == PLAYER2_FAST_SPEED)
									{
   										player2speed = PLAYER2_MED_SPEED;
									}
									else if (player2speed == PLAYER2_MED_SPEED)
									{
										player2speed = PLAYER2_SLOW_SPEED;
									}
									player2up.alive=ACCEL_TIME;
									EraseObject(&player2);
									blast2up.alive=BLAST_TIME;
									Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
								}
   								break;
							}
						}
					 }

				}
				accel2 = player2.action_up;
				
				
				if (player2.action_down && !dccel2)
				{	
   					if ( player2maxshot >=1)
      				{
      					for ( j=0; j<MAX_SHOTS; ++j ) 
      					{
      						if ( ammotot2[j].alive)
      						{
      							ammotot2[j].alive=0;
   								--player2maxshot;
								if (player2.facing==1)
								{
									//printf("facing\n");
									if (player2speed == PLAYER2_FAST_SPEED)
									{
   										player2speed = PLAYER2_MED_SPEED;
									}
									else if (player2speed == PLAYER2_MED_SPEED)
									{
										player2speed = PLAYER2_SLOW_SPEED;
									}
									player2down.alive=ACCEL_TIME;
									EraseObject(&player2);
									blast2down.alive=BLAST_TIME;
									Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
								}
								else
								{
									//printf("not facing\n");
									if (player2speed == PLAYER2_SLOW_SPEED)
									{
   										player2speed = PLAYER2_MED_SPEED;
									}
									else if (player2speed == PLAYER2_MED_SPEED)
									{
										player2speed = PLAYER2_FAST_SPEED;
									}
									player2down.alive=ACCEL_TIME;
									EraseObject(&player2);
									blast2down.alive=BLAST_TIME;
									Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
								}
   								break;
							}
						}
					 }
					 
				}
				dccel2 = player2.action_down;
     		}
			else
			{
				k=rand()%8;
				if (k==1  && player2maxshot >=1)
      			{
					
      				for ( j=0; j<MAX_SHOTS; ++j )
      				{
      					if ( ammotot2[j].alive)
      					{
      						ammotot2[j].alive=0;
   							--player2maxshot;

							if (player2.facing==1)
							{
								//printf("facing\n");
								if (player2speed == PLAYER2_SLOW_SPEED)
								{
   									player2speed = PLAYER2_MED_SPEED;
								}
								else if (player2speed == PLAYER2_MED_SPEED)
								{
									player2speed = PLAYER2_FAST_SPEED;
								}
								player2up.alive=ACCEL_TIME;
								EraseObject(&player2);
								blast2up.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
							else
							{
								//printf("not facing\n");
								if (player2speed == PLAYER2_FAST_SPEED)
								{
   									player2speed = PLAYER2_MED_SPEED;
								}
								else if (player2speed == PLAYER2_MED_SPEED)
								{
									player2speed = PLAYER2_SLOW_SPEED;
								}
								player2up.alive=ACCEL_TIME;
								EraseObject(&player2);
								blast2up.alive=BLAST_TIME;
								Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
							}
   							break;
						}
					}
				}
			else if (k==2 && player2maxshot >=1)
      		{
      			for ( j=0; j<MAX_SHOTS; ++j ) 
      			{
      				if ( ammotot2[j].alive)
      				{
      					ammotot2[j].alive=0;
   						--player2maxshot;
						if (player2.facing==1)
						{
							//printf("facing\n");
							if (player2speed == PLAYER2_FAST_SPEED)
							{
   								player2speed = PLAYER2_MED_SPEED;
							}
							else if (player2speed == PLAYER2_MED_SPEED)
							{
								player2speed = PLAYER2_SLOW_SPEED;
							}
							player2down.alive=ACCEL_TIME;
							EraseObject(&player2);
							blast2down.alive=BLAST_TIME;
							Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
						}
						else
						{
							//printf("not facing\n");
							if (player2speed == PLAYER2_SLOW_SPEED)
							{
   								player2speed = PLAYER2_MED_SPEED;
							}
							else if (player2speed == PLAYER2_MED_SPEED)
							{
								player2speed = PLAYER2_FAST_SPEED;
							}
							player2down.alive=ACCEL_TIME;
							EraseObject(&player2);
							blast2down.alive=BLAST_TIME;
							Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
						}
   						break;
					}
				}
			}
		}	
		
			//if ( player2.alive )
			//{
				player2.y += player2.facing*player2speed;
				if ( player2.y <45 ) 
				{
					player2.y = 45;
					player2.facing = 1;
					player2maxshot =MAX_SHOTS;
					//Mix_PlayChannel(RELOAD_WAV, sounds[RELOAD_WAV], 0);
					for ( i=0; i<MAX_SHOTS; ++i ) 
					{
						ammotot2[i].alive=1;
					}
				} 
				else if( player2.y >= (screen->h-player2.image->h)-75 )
				{
					player2.y = (screen->h-player2.image->h)-75;
					player2.facing = -1;
				}
				
				if ( player2.x < (SCREENWIDTH-105) ) 
				{
					player2.x = SCREENWIDTH-105;
				} 
				else if( player2.x >= (SCREENWIDTH-65) )
				{
					player2.x = (SCREENWIDTH-65);
				}				
			//}
			
			//if ( player.alive ) {
				player.y += player.facing*speed;
				if ( player.y < 45 ) {
					player.y = 45;
					player.facing =1;
					playermaxshot=MAX_SHOTS;
					//Mix_PlayChannel(RELOAD_WAV, sounds[RELOAD_WAV], 0);
					for ( i=0; i<MAX_SHOTS; ++i ) 
					{
						ammotot[i].alive=1;
					}
				} 

				if ( player.y >= (screen->h-player.image->h)-75) {
					player.y = (screen->h-player.image->h)-75;
					player.facing =-1;
				}
			//}
				if ( player.x < 25 ) 
				{
					player.x = 25;
				} 
				else if( player.x >= 65 )
				{
					player.x = 65;
				}	



			/* Move the shots */
			for ( i=0; i<MAX_SHOTS; ++i ) {
				if ( shots[i].alive ) {
					shots[i].x += SHOT_SPEED;
					if ( shots[i].x > SCREENWIDTH-35 ) {
						shots[i].alive = 0;
					}
				}
			}
			
			for ( i=0; i<MAX_SHOTS; ++i ) {
				if ( shots2[i].alive ) {
					shots2[i].x -= SHOT_SPEED;
					if ( shots2[i].x < 35 ) {
						shots2[i].alive = 0;
					}
				}
			}
			/* Detect collisions */
			for ( j=0; j<MAX_SHOTS; ++j ) {
					if ( shots[j].alive && player2.alive && !player2dead.alive &&
						  Collide(&shots[j], &player2) ) {
						player2.alive = 0;
						//playerdead.alive = 0;
						explosions2.x = player2.x;
						explosions2.y = player2.y;
						explosions2.alive = EXPLODE_TIME;
						Mix_PlayChannel(EXPLODE2_WAV,
								sounds[EXPLODE2_WAV], 0);
						shots[j].alive = 0;
						ammotot[j].alive = 0;
						//numberofrounds++;
						lifes =lifes +1;
						for ( int l=0; l<NUMLIFES; ++l ) {
      						 if (life2[l].alive){
	      					 	life2[l].alive=0;
	      					 	EraseObject(&life2[l]);
					 	        break;
				 	        }
			 	        }
						
						notdead =0;
					}
					if ( shots2[j].alive && player.alive && !playerdead.alive &&
						  Collide(&shots2[j], &player) ) {
						player.alive = 0;
						//player2dead.alive = 0;
						explosions.x = player.x;
						explosions.y = player.y;
						explosions.alive = EXPLODE_TIME;
						Mix_PlayChannel(EXPLODE_WAV,
								sounds[EXPLODE_WAV], 0);
						shots2[j].alive = 0;
						ammotot2[j].alive = 0;
						for ( int l=0; l<NUMLIFES; ++l ) {
      						 if (life[l].alive){
	      					 	life[l].alive=0;
	      					 	EraseObject(&life[l]);
					 	        break;
				 	        }
			 	        }
						//numberofrounds++;
						lifes2 =lifes2 +1;
						notdead =0;
					}
				}
			//}

			/* Draw the player2, shots, player, and explosions */
			//if(player2.alive && player.alive)
			//{
				for ( i=0; i<MAX_SHOTS; ++i )
				{
					if ( shots2[i].alive )
					{
						DrawObject(&shots2[i]);
					}
				}
				
				for ( i=0; i<MAX_SHOTS; ++i )
				{
					if ( ammotot2[i].alive )
					{
						DrawObject(&ammotot2[i]);
					}
				}
				
				if (player2down.alive)
				{
					player2down.x=player2.x;
					player2down.y=player2.y;
					DrawObject(&player2down);
				}
				else if (player2up.alive)
				{
					player2up.x=player2.x;
					player2up.y=player2.y;
					DrawObject(&player2up);
				}
				else if (player2dead.alive)
				{
					player2dead.x=player2.x;
					player2dead.y=player2.y;
					DrawObject(&player2dead);
				}
				else if (player2.alive || explosions2.alive)
				{
					DrawObject(&player2);
				}

				if (playerdown.alive)
				{
					playerdown.x=player.x;
					playerdown.y=player.y;
					DrawObject(&playerdown);
				}
				else if (playerup.alive)
				{
					playerup.x=player.x;
					playerup.y=player.y;
					DrawObject(&playerup);
				}
				else if (playerdead.alive)
				{
					playerdead.x=player.x;
					playerdead.y=player.y;
					DrawObject(&playerdead);
				}
				else if (player.alive|| explosions.alive)
				{
					DrawObject(&player);
				}

				if ( blastright.alive) {
					blastright.x=player.x+(player.image->w);
					blastright.y=player.y+(player.image->h/2)-15;
					DrawObject(&blastright);
				}
				if ( blastleft.alive) {
					blastleft.x=player2.x-(player2.image->w);
					blastleft.y=player2.y+(player2.image->h/2)-15;
					DrawObject(&blastleft);
				}

				if ( blastdown.alive) {
					blastdown.x=player.x-5;
					blastdown.y=player.y+(player.image->h);
					DrawObject(&blastdown);
				}
				if ( blastup.alive) {
					blastup.x=player.x+5;
					blastup.y=player.y-(player.image->h);
					DrawObject(&blastup);
				}

				if ( blast2down.alive) {
					blast2down.x=player2.x+8;
					blast2down.y=player2.y+(player2.image->h);
					DrawObject(&blast2down);
				}

				if ( blast2up.alive) {
					blast2up.x=player2.x-5;
					blast2up.y=player2.y-(player2.image->h);
					DrawObject(&blast2up);
				}

				for ( i=0; i<MAX_SHOTS; ++i )
				{
					if ( shots[i].alive )
					{
						DrawObject(&shots[i]);
					}
				}
				
				for ( i=0; i<MAX_SHOTS; ++i ) 
				{
					if ( ammotot[i].alive ) 
					{
						DrawObject(&ammotot[i]);
					}
				}
				
				for ( i=0; i<NUMLIFES; ++i ) 
				{
					if ( life[i].alive ) 
					{
						DrawObject(&life[i]);
					}
					if ( life2[i].alive ) 
					{
						DrawObject(&life2[i]);
					}
				}
//				for ( i=0; i<numberofrounds; ++i ) 
//				{
					if ( scorenum.alive) 
					{
						DrawObject(&scorenum);
					}
					if ( scorenum2.alive ) 
					{
						DrawObject(&scorenum2);
					}
//				}
			//}
			DrawObject(&tramp);
			DrawObject(&tramp2);
			DrawObject(&reload);
			DrawObject(&reload2);

			if ( explosions.alive ) {
				DrawObject(&explosions);
			}
			if ( explosions2.alive ) {
				DrawObject(&explosions2);
			}
			UpdateScreen();



			/* Loop the music */
	#if defined(PLAY_MOD) || defined(PLAY_MID)
			if ( ! Mix_PlayingMusic() ) {
				Mix_PlayMusic(music, 0);
			}
	#else
			if ( ! Mix_Playing(MUSIC_WAV) ) {
				Mix_PlayChannel(MUSIC_WAV, sounds[MUSIC_WAV], 0);
			}
	#endif

			}
		}

		/* Wait for the player to finish exploding */
		while ( Mix_Playing(EXPLODE_WAV) || Mix_Playing(EXPLODE2_WAV)) {
			WaitFrame();
		}


		//keys = SDL_GetKeyState(NULL);
  		notdead =1;

		if (!player2.alive)
		{
			player2dead.alive=DEADTIME;
		}
		
		if (!player.alive)
  		{ 
			playerdead.alive=DEADTIME;
		}
	
		if ( (lifes == NUMLIFES+1) )
		{
			if (scorenum.alive)
			{
				EraseObject(&scorenum);
				UpdateScreen();
			}
			scorenum.alive=1;
			scorenum.x = 180;
			scorenum.y = 410;

			scorenum.image = numbers[score+1].image;
			DrawObject(&scorenum);
				
			if ( ++score == numberofrounds)
			{
					return;
			}
			lifes=0;
			lifes2=0;
			for ( i=0; i<NUMLIFES; ++i ) {
				life[i].alive = 1;
				life2[i].alive = 1;
				if ( life[i].alive ) 
				{
					DrawObject(&life[i]);
				}
				if ( life2[i].alive ) 
				{
					DrawObject(&life2[i]);
				}
			}
			UpdateScreen();
			player.alive = 1;
			player2.alive = 1;
			playerdead.alive = 0;
			player2dead.alive = 0;	

			newround=1;
			roundcount++;
		}
		
		if ( lifes2 == NUMLIFES+1 )
		{
			if (scorenum2.alive)
			{
				EraseObject(&scorenum2);
				UpdateScreen();
			}		
			scorenum2.alive=1;
			scorenum2.alive=1;
			scorenum2.x = (SCREENWIDTH-200);
			scorenum2.y = 410;
			scorenum2.image = numbers[score2+1].image;
			DrawObject(&scorenum2);
			UpdateScreen();
			if ( ++score2 == numberofrounds)
			{
					return;
			}
			lifes=0;
			lifes2=0;
			for ( i=0; i<NUMLIFES; ++i ) {
				life[i].alive = 1;
				life2[i].alive = 1;
				if ( life[i].alive ) 
				{
					DrawObject(&life[i]);
				}
				if ( life2[i].alive ) 
				{
					DrawObject(&life2[i]);
				}
			}
			UpdateScreen();
			player.alive = 1;
			player2.alive = 1;
			playerdead.alive = 0;
			player2dead.alive = 0;	

			newround=1;
			roundcount++;		
		}
		



			


	}
	

	Mix_HaltChannel(-1);
	return;
}
int DisplayMenu(void)
{
	int roundnumber=2;
	SDL_PollEvent(&event);
	keys = SDL_GetKeyState(NULL);
	if (MENU)
	{


		if ( ! Mix_Playing(TITLE_WAV) ) {
			Mix_PlayChannel(TITLE_WAV, sounds[TITLE_WAV], 0);
		}
		SDL_BlitSurface( title, NULL, screen, NULL);
	    SDL_Flip(screen); 
	    
  		vsbattle.x=230;
    	vsbattle.y=320; 
		DrawObject(&vsbattle);
		
		numbers[2].x=230;
    	numbers[2].y=370;
    	DrawObject(&numbers[2]);
    	
  		round.x=260;
    	round.y=370; 
		DrawObject(&round);		

    	iconptr.x=100;
    	iconptr.y=310; 
		DrawObject(&iconptr);	
		blastright.alive=0;
		UpdateScreen();
		
		int menuloc=1;
		int down,up,started,fire=0;
		int down2,up2,started2,fire2=0;
		keys = SDL_GetKeyState(NULL);
		while (1)//!(keys[SDLK_ESCAPE] == SDL_PRESSED) && !(keys[SDLK_SPACE] == SDL_PRESSED) && !JOY_START(0) && !JOY_START(1) )
		{
						/* Poll input queue, run keyboard loop */
			while ( SDL_PollEvent(&event) ) {
				if ( event.type == SDL_QUIT )
					break;
	
			}
			if ( keys[SDLK_ESCAPE] == SDL_PRESSED ) {
				exitgame =1;
				break;
			}
			update_player_actions();
			if (( player.action_start && !started ) ||( player2.action_start && !started2 ))
			{
				break;
			}
			started=player.action_start;
			started2=player2.action_start;

			if ( ! Mix_Playing(TITLE_WAV) ) {
				Mix_PlayChannel(TITLE_WAV, sounds[TITLE_WAV], 0);
			}

			if ((player.action_down && !down) || (player2.action_down && !down2))
			{	
				Paintbackground(title);
 				iconptr.x=100;
  			  	iconptr.y=360; 
  			  	numbers[roundnumber].alive=1;
  			  	menuloc=2;
			}
			down = player.action_down;
			down2 = player2.action_down;

			if ((player.action_up && !up) || (player2.action_up && !up2))
			{	
				Paintbackground(title);
 				iconptr.x=100;
  			  	iconptr.y=310; 
  			  	numbers[roundnumber].alive=1;
  			  	menuloc=1;
			}
			up = player.action_up;
			up2 = player2.action_up;

			if ((player.action_fire && !fire ) || (player2.action_fire && !fire2 ))
			{	

				if (menuloc==2)
				{
					Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
					Paintbackground(title);
					blastright.alive=5;
					blastright.x=212;
					blastright.y=370;
					DrawObject(&blastright);
					EraseObject(&numbers[roundnumber]);
					if (roundnumber <5)
						roundnumber++;
					else if (roundnumber == 5)
	    				roundnumber=1;	
					numbers[roundnumber].x=numbers[2].x;
	    			numbers[roundnumber].y=numbers[2].y;
	    			numbers[roundnumber].alive=1;
    			}
    			if (menuloc==1)
    			{
					blastright.x=212;
					blastright.y=320;
					DrawObject(&blastright);
					UpdateScreen();
					Mix_PlayChannel(SHOT_WAV, sounds[SHOT_WAV], 0);
					while ( Mix_Playing(SHOT_WAV)) {
					WaitFrame();
					}
    				break;
   				}
			}
			fire = player.action_fire;	
			fire2 = player2.action_fire;
			
   			if (blastright.alive >0)
			{
				Paintbackground(title);
				blastright.alive--;
				DrawObject(&blastright);
				
			}
			else if (numbers[roundnumber].alive == 1)
			{   
				numbers[roundnumber].alive=0;
   				Paintbackground(title);
	    		DrawObject(&numbers[roundnumber]);
            }   	
			DrawObject(&vsbattle);
			DrawObject(&iconptr);	
			DrawObject(&round);	

			UpdateScreen();
		}
	
	}
	Mix_HaltChannel(-1);
	return roundnumber;
}
int main(int argc, char *argv[])
{

	/* Initialize the SDL library */
	if ( SDL_Init(SDL_INIT_AUDIO|SDL_INIT_VIDEO|SDL_INIT_JOYSTICK) < 0 ) {
		fprintf(stderr, "Couldn't initialize SDL: %s\n",SDL_GetError());
		exit(2);
	}
	int i;

	num_joys = SDL_NumJoysticks();
	for(i = 0; i < 4 && i < num_joys; ++i)
		joys[i] = SDL_JoystickOpen(i);

  	#ifndef _arch_dreamcast
	atexit(SDL_Quit);
	#endif
	int numberofplayers=2;
	int numberofrounds=numberofrounds;
	speed=PLAYER_MED_SPEED;
	player2speed=PLAYER2_MED_SPEED;
	exitgame=0;
	/* Open the audio device */
	if ( Mix_OpenAudio(11025, AUDIO_U8, 1, 512) < 0 ) {
		fprintf(stderr,
		"Warning: Couldn't set 11025 Hz 8-bit audio\n- Reason: %s\n",
							SDL_GetError());
	}

	/* Open the display device */
  	#ifdef _arch_dreamcast
	screen = SDL_SetVideoMode(SCREENWIDTH, SCREENHEIGHT , 8, SDL_SWSURFACE|SDL_FULLSCREEN);
	#else
	screen = SDL_SetVideoMode(SCREENWIDTH, SCREENHEIGHT , 8, SDL_SWSURFACE);//|SDL_FULLSCREEN);
	SDL_WM_SetCaption("Trampalien Gunmen DC", "TGDC");
	SDL_WM_SetIcon(LoadImage(DATAFILE("icon.gif"),0),NULL);

	
	#endif
	if ( screen == NULL ) {
		fprintf(stderr, "Couldn't set video mode: %s\n",
							SDL_GetError());
		exit(2);
	}

	/* Initialize the random number generator */
	srand(time(NULL));

  	// We also hide the cursor
  	SDL_ShowCursor(0);

	/* Load the music and artwork */
	if ( LoadData() ) 
	{

		/* Run the game */
		while (!exitgame)
		{
			numberofrounds = DisplayMenu();
			
   			if(exitgame)
				return 0;
				
			speed=PLAYER_MED_SPEED;
			player2speed=PLAYER2_MED_SPEED;
			playerdead.alive=0;
			player2dead.alive=0;

			scorenum.alive=0;
			scorenum2.alive=0;
			
			RunGame(numberofrounds,numberofplayers);
				  
			if(exitgame)
				return 0;

			if(!menu)
			{
				menu=0;
				playerwins.x=150;
				playerwins.y=100;
				player2wins.x=150;
				player2wins.y=100;
				
				Mix_HaltChannel(-1);
				if (score > score2)
				{
					Mix_PlayChannel(PWIN_WAV, sounds[PWIN_WAV], 0);

					//printf("player 1 wins\n");
					DrawObject(&playerwins);
					playerwins.alive=1;
					UpdateScreen();
					while ( Mix_Playing(PWIN_WAV)) {
						WaitFrame();
					}
				}
				else if (score2 > score)
				{
					Mix_PlayChannel(P2WIN_WAV, sounds[P2WIN_WAV], 0);

					//printf("player 2 wins\n");
					DrawObject(&player2wins);
					player2wins.alive=1;
					UpdateScreen();
					while ( Mix_Playing(P2WIN_WAV)) {
						WaitFrame();
					}
				}
				keys = SDL_GetKeyState(NULL);  
				while (1)// !(keys[SDLK_ESCAPE] == SDL_PRESSED) && !(keys[SDLK_SPACE] == SDL_PRESSED) && !JOY_START(0) && !JOY_START(1) )
				{
								/* Poll input queue, run keyboard loop */
					while ( SDL_PollEvent(&event) ) {
						if ( event.type == SDL_QUIT )
							return 0;
		
					}
	        		update_player_actions();
					if ( player.action_start && !startbutton )
					{
						break;
					}
					startbutton=player.action_start;
				}
		

					if (playerwins.alive){
					 EraseObject(&playerwins);
					 playerwins.alive=0;
					 UpdateScreen();
					}
					else if (player2wins.alive)
					{
						EraseObject(&player2wins);
						player2wins.alive=0;
						UpdateScreen();
					}
					score=score2=0;
					Mix_HaltChannel(-1);
				
			}
		}
		/* Free the music and artwork */
		FreeData();
	}
	
	/* Quit */
	Mix_CloseAudio();
	exit(0);
}
